@@ -11,6 +11,7 @@
 #include "command.h"
 #include "debuginfo.h"
 #include "findresultwidget.h"
+#include "findwidget.h"
 #include "flagrow-master.h"
 #include "headingeditor.h"
 #include "macros.h"
@@ -58,7 +59,7 @@ BranchPropertyEditor *branchPropertyEditor;
 Main *mainWindow;
 ScriptEditor *scriptEditor;
 ScriptOutput *scriptOutput;
-FindControlsWidget *findControlsWidget;
+FindWidget *findWidget;
 FindResultWidget *findResultWidget;
 TaskEditor *taskEditor;
 
@@ -68,16 +69,15 @@ FlagRowMaster *userFlagsMaster;
 
 Macros macros;
 
-ulong itemLastID = 0;       // Unique ID for all items in all models
-ulong imageLastID = 0;      // Unique ID for caching images, also flags not in tree
+ulong itemLastID = 0;  // Unique ID for all items in all models
+ulong imageLastID = 0; // Unique ID for caching images, also flags not in tree
 
-QDir tmpVymDir;             // All temp files go there, created in mainwindow
-QDir cacheDir;              // tmp dir with cached svg files in tmpVymDir
-QDir clipboardDir;          // Clipboard used in all mapEditors
-QString clipboardFileName;  // Clipboard used in all mapEditors
+QDir tmpVymDir;          // All temp files go there, created in mainwindow
+QDir cacheDir;            // tmp dir with cached svg files in tmpVymDir
+QString clipboardDir;    // Clipboard used in all mapEditors
+QString clipboardFile;   // Clipboard used in all mapEditors
 
 QDir vymBaseDir;            // Containing all styles, scripts, images, ...
-QDir vymUserDir;            // User directory with temporary files
 
 bool useActionLog;          // Write logfile. No GUI yet to enable, only for debugging
 QString actionLogPath;      // Path to logfile
@@ -114,11 +114,10 @@ bool unzipToolAvailable = false;
 QString zipToolPath;	// Platform dependant zip tool
 QString unzipToolPath;  // Platform dependant unzip tool
 
+QList<Command *> vymCommands;
+QList<Command *> modelCommands;
 QList<Command *> branchCommands;
 QList<Command *> imageCommands;
-QList<Command *> itemListCommands;
-QList<Command *> modelCommands;
-QList<Command *> vymCommands;
 QList<Command *> xlinkCommands;
 
 Options options;
@@ -127,22 +126,15 @@ ImageIO imageIO;
 bool usingDarkTheme;    // Influences some color schemes
 bool systemSeemsDark;   // Text brighter than background?
 QString iconTheme;      // "bright" or "dark" depending on usingDarkTheme
-
-// Some colors used more often and depending on dark mode
-QColor vymBlueColor;
-QColor vymForegroundColor;
-QColor vymBaseColor;
+QColor vymBlue;
 
 int warningCount = 0;
 int criticalCount = 0;
 int fatalCount = 0;
 
-// Some styles used in various widgets
-QString editorFocusInStyle =
-    QString(" border-color: #3daee9; border-style:outset; border-width:1px; "
+QString editorFocusStyle =
+    QString(" border-color: #3daee9; border-style:outset; border-width:3px; "
             "color:black;");
-QString editorFocusOutStyle = QString("border-width:0px;");
-QString toolBarStyle;
 
 void msgHandler(QtMsgType type, const QMessageLogContext &context,
                 const QString &msg)
@@ -308,7 +300,7 @@ int main(int argc, char *argv[])
         } else {
             // ok, let's find vymBaseDir on my own
 
-#if defined(Q_OS_MACOS)
+#if defined(Q_OS_MACX)
             // Executable is in vym.app/Contents/MacOS, so go up first:
             vymBaseDir.setPath(QCoreApplication::applicationDirPath());
             vymBaseDir.cdUp();
@@ -320,60 +312,6 @@ int main(int argc, char *argv[])
 #endif
         }
 
-    // Temporary directories
-
-    // vymUserDir has temporary files (later maybe more data)
-    // in users home to avoid deleting still
-    // required files by system (see #151)
-
-    vymUserDir.setPath(QDir::homePath() + "/.vym");
-
-    bool ok;
-    if (!vymUserDir.exists()) {
-        ok = QDir::home().mkdir(
-                basename(vymUserDir.path()),
-                QFileDevice::ReadOwner| QFileDevice::WriteOwner | QFileDevice::ExeOwner);
-        if (!ok) {
-            QString msg = "Failed to create vymUserDir=" + vymUserDir.path();
-            qWarning() << msg;
-            QMessageBox::warning(0, "Critical Error", msg);
-            exit (1);
-        }
-    }
-
-    tmpVymDir.setPath(makeTmpDir(ok, "vym-tmp"));
-    if (!ok) {
-        QString msg = "Failed to create temporary directory tmpVymDir=" + tmpVymDir.path();
-        qWarning() << msg;
-        QMessageBox::warning(0, "Critical Error", msg);
-        exit(1);
-    }
-    if (debug)
-        qDebug() << "tmpVymDirPath = " << tmpVymDir.path();
-
-    // Create directory for clipboard
-    clipboardDir.setPath(tmpVymDir.path() + "/clipboard");
-    clipboardFileName = "clipboard";
-    if (!clipboardDir.mkpath(clipboardDir.path())) {
-        QString msg = "Failed to create clipboardDir=" + clipboardDir.path();
-        qWarning() << msg;
-        QMessageBox::warning(0, "Critical Error", msg);
-        exit(1);
-    }
-
-    makeSubDirs(clipboardDir.path());
-
-    // Create directory for cached files, e.g. svg images
-    cacheDir.setPath(tmpVymDir.path() + "/cache");
-    if (!tmpVymDir.mkpath(cacheDir.path())) {
-        QString msg = "Failed to create cache directory cacheDir=" + cacheDir.path();
-        qWarning() << msg;
-        QMessageBox::warning(0, "Critical Error", msg);
-        exit(1);
-    }
-
-
-
     // Platform specific settings
     vymPlatform = QSysInfo::prettyProductName();
 
@@ -435,25 +373,21 @@ int main(int argc, char *argv[])
             iconTheme = "dark";
         }
     }
-    /*
-    qDebug() << "dark settings: " << settingsDarkTheme
-        << " systemDark=" << systemSeemsDark
-        << " useDark" << usingDarkTheme;
-    */
 
-    QPalette palette;
-    if (usingDarkTheme) {
+    if (usingDarkTheme && settingsDarkTheme == "always") {
         qApp->setStyle(QStyleFactory::create("fusion"));
         //qApp->setStyle(QStyleFactory::create("Windows"));
         //qApp->setStyle(QStyleFactory::create("windowsvista"));
 
         // On Windows, there is no dark palette predefined, let's do that on our own
+        QPalette palette;
         palette.setColor(QPalette::Window, QColor(53,53,53));
         palette.setColor(QPalette::WindowText, Qt::white);
         palette.setColor(QPalette::Base, QColor(27, 30, 32));
         palette.setColor(QPalette::AlternateBase, QColor(53,53,53));
         palette.setColor(QPalette::ToolTipBase, QColor(53,53,53));
         palette.setColor(QPalette::ToolTipText, Qt::white);
+        // Unused: QPalette::PlaceHolderText
         palette.setColor(QPalette::Text, Qt::white);
         palette.setColor(QPalette::Button, QColor(53,53,53));
         palette.setColor(QPalette::ButtonText, Qt::white);
@@ -465,54 +399,8 @@ int main(int argc, char *argv[])
         //palette.setColor(QPalette::Light, Qt::green);
         //palette.setColor(QPalette::Midlight, Qt::red);
         qApp->setPalette(palette);
-
-        vymBlueColor =QColor::fromString("#00aaff");
-    } else {
-        if (systemSeemsDark) {
-            qApp->setStyle(QStyleFactory::create("macOS"));
-            palette.setColor(QPalette::Window, QColor("#ececec"));          // 10
-            palette.setColor(QPalette::WindowText, Qt::black);              //  0
-            palette.setColor(QPalette::Base, QColor("#ffffff"));            //  9
-            palette.setColor(QPalette::AlternateBase, QColor(253,53,53));   // 16
-            palette.setColor(QPalette::ToolTipBase, Qt::white);             // 18
-            palette.setColor(QPalette::ToolTipText, Qt::black);             // 19
-            palette.setColor(QPalette::Text, Qt::black);                    //  6
-            palette.setColor(QPalette::Button, QColor("#ececec"));          //  1
-            palette.setColor(QPalette::ButtonText, Qt::black);              //  8
-            palette.setColor(QPalette::BrightText, Qt::white);              //  7
-
-            /*
-            QPalette::Light	2	Lighter than Button color.
-            QPalette::Midlight	3	Between Button and Light.
-            QPalette::Dark	4	Darker than Button.
-            QPalette::Mid	5	Between Button and Dark.
-            QPalette::Shadow	11	A very dark color. By default, shadow color is Qt::black.
-            */
-            palette.setColor(QPalette::Light, QColor("#ffffff"));           //  2
-            palette.setColor(QPalette::Midlight, QColor("#f5f5f5"));        //  3
-            palette.setColor(QPalette::Dark, QColor("#bfbfbf"));            //  4
-            palette.setColor(QPalette::Mid, QColor("#a9a9a9"));             //  5
-            palette.setColor(QPalette::Shadow, Qt::black);                  // 11
-
-            // Roles of seleced items
-            palette.setColor(QPalette::Highlight, QColor("#a5cdff"));       // 12
-            palette.setColor(QPalette::HighlightedText, Qt::black);         // 13
-
-            // Links
-            /*
-            QPalette::Link	14
-            QPalette::LinkVisited	15
-             */
-            qApp->setPalette(palette);
-        }
-
-        vymBlueColor =QColor::fromString("#0000ff");
     }
 
-    toolBarStyle = "background-color: " + palette.color(QPalette::Button).name() + "; border: None;";
-    vymForegroundColor = palette.color(QPalette::WindowText);
-    vymBaseColor = palette.color(QPalette::Base);
-
     // Prepare and check translations
     vymTranslationsDir = QDir(vymBaseDir.path() + "/translations");
     vymTranslationsDir.setFilter(QDir::AllEntries | QDir::NoDotAndDotDot);
@@ -577,7 +465,6 @@ int main(int argc, char *argv[])
 
     // Initialize editors
     noteEditor = new NoteEditor(QObject::tr("Note Editor", "Name of editor shown as window title"));
-
     headingEditor = new HeadingEditor(QObject::tr("Heading Editor", "Name of editor shown as window title"));
     branchPropertyEditor = new BranchPropertyEditor();
 
@@ -585,27 +472,14 @@ int main(int argc, char *argv[])
     // overwritten during loading of maps
     lastSessionFiles = settings.value("/mainwindow/sessionFileList", QStringList()).toStringList();
 
+
     // Logfiles (no GUI yet for settings)
     useActionLog = settings.value("/logfile/enabled", false).toBool();
     actionLogPath = settings.value("/logfile/path", QDir::homePath() + "/vym.log").toString();
 
-    // Create MainWindow (after creating editors)
+    // Create MainWindow
     Main m;
 
-    // Add Escape-keys to editors (after creating MainWindow)
-    QAction *a = new QAction("Cancel", noteEditor);
-    a->setShortcut(Qt::Key_Escape);     // Escape in NoteEditor
-    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    noteEditor->connect(a, SIGNAL(triggered()), mainWindow, SLOT(escapePressed()));
-    noteEditor->addAction(a);
-
-    a = new QAction("Cancel", headingEditor);
-    a->setShortcut(Qt::Key_Escape);     // Escape in HeadingEditor
-    a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    headingEditor->connect(a, SIGNAL(triggered()), mainWindow, SLOT(escapePressed()));
-    headingEditor->addAction(a);
-
-
     // Check for zip tools
     zipToolAvailable = ZipAgent::checkZipTool();
     unzipToolAvailable = ZipAgent::checkUnzipTool();
@@ -704,19 +578,17 @@ int main(int argc, char *argv[])
         m.runScript(scriptEditor->getScriptFile());
     }
 
+    // For benchmarking we may want to quit instead of entering event loop
+    if (options.isActive("quit"))
+        return 0;
+
     // Enable some last minute cleanup
     QObject::connect(&app, SIGNAL(lastWindowClosed()), &app, SLOT(quit()));
 
-    // For benchmarking or if test script is done
-    // we may want to quit instead of entering event loop
-    if (options.isActive("quit") || m.exitAfterScript())
-        m.fileExitVYM();
-    else
-        app.exec();
+    app.exec();
 
     // Cleanup
     delete noteEditor;
-    removeDir(tmpVymDir);
 
     int s = warningCount + criticalCount + fatalCount;
     if (s > 0)
