@@ -70,7 +70,7 @@ class Main : public QMainWindow {
     void setupAPI();
 
     /*! Helper method to clone actions later in MapEditor */
-    void cloneActionMapEditor(QAction *a);
+    void cloneActionMapEditor(QAction *a, QKeySequence ks);
 
     void setupFileActions();
     void setupEditActions();
@@ -117,13 +117,7 @@ class Main : public QMainWindow {
   private slots:
     void editorChanged();
 
-  private:
-    int backgroundZipProcesses;
-    bool closeAfterLastZipProcess;
-
   public slots:
-    void backgroundZipStarted();
-    void backgroundZipFinished();
     bool fileLoad(QString, const File::LoadMode &, const File::FileType &ftype);
     void fileLoad(const File::LoadMode &);
   private slots:
@@ -167,24 +161,12 @@ class Main : public QMainWindow {
     void fileExportLast();
     bool fileCloseMap(int i = -1); // Optionally pass number of tab
     void filePrint();
-
-  public:
-    bool exitAfterScript();
-    void setExitAfterScript(bool b);
-
-  private:
-    bool exitAfterScriptInt;
-    QString repeatActionInt;
-
-  public:
-    void setRepeatAction(const QString &script);
+    bool fileExitVYM();
 
   public slots:
-    bool fileExitVYM();
     void editUndo();
     void editRedo();
     void gotoHistoryStep(int);
-
   private slots:
     void editCopy();
     void editPaste();
@@ -192,13 +174,14 @@ class Main : public QMainWindow {
 
   public slots:
     void updateQueries(VymModel *);
-    bool openUrl(const QString &url = "", bool privateMode = false);
-    void openTabs(QStringList, bool privateMode = false);
+    bool openURL(const QString &url);
+    void openTabs(QStringList);
+    void editOpenURL();
+    void editOpenURLTab();
 
   private slots:
-    void editOpenMultipleVisUrls(bool ignoreScrolled = true, bool privateMode = false);
-    void editOpenMultipleUrls();
-    void editOpenMultipleUrlsPrivate();
+    void editOpenMultipleVisURLTabs(bool ignoreScrolled = true);
+    void editOpenMultipleURLTabs();
     void editNote2URLs();
     void editURL();
     void editLocalURL();
@@ -241,7 +224,6 @@ class Main : public QMainWindow {
     void editGrowSelectionSize();
     void editShrinkSelectionSize();
     void editResetSelectionSize();
-    void editRepeatLastAction();
     void editAddMapCenter();
     void editAddBranch();
     void editAddBranchBefore();
@@ -255,9 +237,9 @@ class Main : public QMainWindow {
     void editDeleteSelection();
     void editLoadImage();
     void editSaveImage();
+    void popupFollowXLink();
+    void editFollowXLink(QAction *);
     void editEditXLink(QAction *);
-    void popupFollowReference();
-    void followReference(QAction *);
 
   private slots:
     bool initLinkedMapsMenu(VymModel *model, QMenu *menu);
@@ -270,8 +252,6 @@ class Main : public QMainWindow {
     bool initTargetsMenu(VymModel *model, QMenu *menu);
     void editGoToTarget();
     void editMoveToTarget();
-    void editSelectFirstSibling();
-    void editSelectLastSibling();
     void editSelectPrevious();
     void editSelectNext();
     void editSelectNothing();
@@ -342,17 +322,18 @@ class Main : public QMainWindow {
     bool settingsConfluence();
     bool settingsJIRA();
 
-    void windowShowNoteEditor();
-    void switchEditors();
+    void windowToggleNoteEditor();
+    void windowToggleTreeEditors();
     void windowSetTreeEditorsVisibility(bool);
     void windowToggleTaskEditor();
-    void windowShowSlideEditors();
+    void windowToggleSlideEditors();
     void windowSetSlideEditorsVisibility(bool);
     void windowToggleScriptEditor();
     void windowToggleScriptOutput();
     void windowToggleHistory();
     void windowToggleProperty();
     void windowShowHeadingEditor();
+    void windowToggleHeadingEditor();
     void updateHistory(SimpleSettings &);
     void windowToggleAntiAlias();
     bool isAliased();
@@ -375,7 +356,6 @@ class Main : public QMainWindow {
 
     void scriptPrint(const QString &, const QString &color = "");
     QVariant runScript(const QString &);
-    QVariant runScriptWithMacros(const QString &);
     void abortScript(const QJSValue::ErrorType &err, const QString &msg);
     void abortScript(const QString &msg);
     QVariant setScriptResult(const QVariant &r);
@@ -437,6 +417,7 @@ class Main : public QMainWindow {
   private:
     QString shortcutScope; //! For listing shortcuts
     QTabWidget *tabWidget;
+    qint64 *browserPID;
 
     QStringList imageTypes;
 
@@ -486,8 +467,7 @@ class Main : public QMainWindow {
     QToolBar *selectionToolbar;
     QToolBar *editorsToolbar;
     QToolBar *colorsToolbar;
-    QToolBar *viewTransformationsToolbar;
-    QToolBar *limitedViewToolbar;
+    QToolBar *zoomToolbar;
     QToolBar *modModesToolbar;
     QToolBar *referencesToolbar;
     QToolBar *standardFlagsToolbar;
@@ -510,14 +490,10 @@ class Main : public QMainWindow {
     QAction *actionFileExportLast;
     QAction *actionFileExportConfluence;
     QAction *actionUndo;
-    QAction *actionUndoVim;
     QAction *actionRedo;
-    QAction *actionRepeatCommand;
     QAction *actionCopy;
-    QAction *actionCopyVim;
     QAction *actionCut;
     QAction *actionPaste;
-    QAction *actionPasteVim;
     QAction *actionMoveUp;
     QAction *actionMoveDown;
     QAction *actionMoveDownDiagonally;
@@ -530,16 +506,15 @@ class Main : public QMainWindow {
     QAction *actionExpandOneLevel;
     QAction *actionCollapseOneLevel;
     QAction *actionCollapseUnselected;
-    QAction *actionOpenUrl;
-    QAction *actionOpenMultipleVisUrls;
-    QAction *actionOpenMultipleUrls;
-    QAction *actionOpenMultipleUrlsPrivate;
+    QAction *actionOpenURL;
+    QAction *actionOpenURLTab;
+    QAction *actionOpenMultipleVisURLTabs;
+    QAction *actionOpenMultipleURLTabs;
     QAction *actionGetURLsFromNote;
     QAction *actionURLNew;
     QAction *actionLocalURL;
     QAction *actionHeading2URL;
     QAction *actionGetJiraDataSubtree;
-    QAction *actionSetJiraQuery;
     QAction *actionGetConfluencePageDetails;
     QAction *actionGetConfluencePageDetailsRecursively;
     QAction *actionOpenVymLink;
@@ -567,7 +542,7 @@ class Main : public QMainWindow {
     QAction *actionMapInfo;
     QAction *actionHeading;
     QAction *actionDelete;
-    QAction *actionDeleteVim;
+    QAction *actionDeleteAlt;
 
   public:
     QAction *actionAddMapCenter;
@@ -592,16 +567,10 @@ class Main : public QMainWindow {
     QAction *actionGoToTargetLinkedMap;
     QAction *actionGoToTarget;
     QAction *actionMoveToTarget;
-    QAction *actionSelectFirstSibling;
-    QAction *actionSelectFirstSiblingVim;
-    QAction *actionSelectLastSibling;
-    QAction *actionSelectLastSiblingVim;
     QAction *actionSelectPrevious;
     QAction *actionSelectNext;
     QAction *actionSelectNothing;
     QAction *actionFind;
-    QAction *actionFindVim;
-    QAction *actionFollowReference;
 
     QActionGroup *actionGroupQuickColors;
     QAction *actionFormatQuickColor;
@@ -647,8 +616,12 @@ class Main : public QMainWindow {
     QAction *actionViewToggleNoteEditor;
     QAction *actionViewToggleHeadingEditor;
     QAction *actionViewToggleTaskEditor;
-    QAction *actionViewSwitchEditors;
-    QAction *actionViewShowSlideEditors;
+  
+  public: // Allow VymView class to check visibility  
+    QAction *actionViewToggleTreeEditor;
+    QAction *actionViewToggleSlideEditor;
+
+  private:  
     QAction *actionViewToggleScriptEditor;
     QAction *actionViewToggleScriptOutput;
     QAction *actionViewToggleHistoryWindow;
@@ -659,6 +632,7 @@ class Main : public QMainWindow {
 
     QAction *actionConnectGetConfluenceUser;
     QAction *actionSettingsAutoSelectNewBranch;
+    QAction *actionSettingsAutoSelectText;
     QAction *actionSettingsUseFlagGroups;
     QAction *actionSettingsUseHideExport;
     QAction *actionSettingsToggleAutosave;
